"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAccountFetchHelpersFragment = void 0;
const common_1 = require("./common");
function getAccountFetchHelpersFragment(scope) {
    const { accountNode, typeManifest, nameApi, customAccountData } = scope;
    const hasCustomData = customAccountData.has(accountNode.name);
    const accountTypeFragment = hasCustomData
        ? typeManifest.strictType.clone()
        : (0, common_1.fragment)(nameApi.dataType(accountNode.name));
    const decoderFunctionFragment = hasCustomData
        ? typeManifest.decoder.clone()
        : (0, common_1.fragment)(`${nameApi.decoderFunction(accountNode.name)}()`);
    return (0, common_1.fragmentFromTemplate)('accountFetchHelpers.njk', {
        decoderFunction: decoderFunctionFragment.render,
        accountType: accountTypeFragment.render,
        decodeFunction: nameApi.accountDecodeFunction(accountNode.name),
        fetchFunction: nameApi.accountFetchFunction(accountNode.name),
        fetchMaybeFunction: nameApi.accountFetchMaybeFunction(accountNode.name),
        fetchAllFunction: nameApi.accountFetchAllFunction(accountNode.name),
        fetchAllMaybeFunction: nameApi.accountFetchAllMaybeFunction(accountNode.name),
    })
        .mergeImportsWith(accountTypeFragment, decoderFunctionFragment)
        .addImports('solanaAddresses', ['Address'])
        .addImports('solanaAccounts', [
        'Account',
        'assertAccountExists',
        'assertAccountsExist',
        'decodeAccount',
        'EncodedAccount',
        'fetchEncodedAccount',
        'fetchEncodedAccounts',
        'FetchAccountConfig',
        'FetchAccountsConfig',
        'MaybeAccount',
        'MaybeEncodedAccount',
    ]);
}
exports.getAccountFetchHelpersFragment = getAccountFetchHelpersFragment;
//# sourceMappingURL=accountFetchHelpers.js.map