"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAccountPdaHelpersFragment = void 0;
const nodes_1 = require("../../../nodes");
const common_1 = require("./common");
function getAccountPdaHelpersFragment(scope) {
    const { accountNode, programNode, nameApi, linkables, customAccountData, typeManifest, } = scope;
    const pdaNode = accountNode.pda ? linkables.get(accountNode.pda) : undefined;
    if (!pdaNode) {
        return (0, common_1.fragment)('');
    }
    const accountTypeFragment = customAccountData.has(accountNode.name)
        ? typeManifest.strictType.clone()
        : (0, common_1.fragment)(nameApi.dataType(accountNode.name));
    const importFrom = 'generatedPdas';
    const pdaSeedsType = nameApi.pdaSeedsType(pdaNode.name);
    const findPdaFunction = nameApi.pdaFindFunction(pdaNode.name);
    const hasVariableSeeds = pdaNode.seeds.filter((0, nodes_1.isNodeFilter)('variablePdaSeedNode')).length > 0;
    return (0, common_1.fragmentFromTemplate)('accountPdaHelpers.njk', {
        accountType: accountTypeFragment.render,
        pdaSeedsType,
        findPdaFunction,
        fetchFunction: nameApi.accountFetchFunction(accountNode.name),
        fetchMaybeFunction: nameApi.accountFetchMaybeFunction(accountNode.name),
        fetchFromSeedsFunction: nameApi.accountFetchFromSeedsFunction(accountNode.name),
        fetchMaybeFromSeedsFunction: nameApi.accountFetchMaybeFromSeedsFunction(accountNode.name),
        program: programNode,
        hasVariableSeeds,
    })
        .mergeImportsWith(accountTypeFragment)
        .addImports(importFrom, hasVariableSeeds ? [pdaSeedsType, findPdaFunction] : [findPdaFunction])
        .addImports('solanaAddresses', ['Address'])
        .addImports('solanaAccounts', [
        'Account',
        'assertAccountExists',
        'FetchAccountConfig',
        'MaybeAccount',
    ]);
}
exports.getAccountPdaHelpersFragment = getAccountPdaHelpersFragment;
//# sourceMappingURL=accountPdaHelpers.js.map